@@ -13,7 +13,7 @@ from ._utils import get_config_attr, utcnow
 if TYPE_CHECKING:
     from ._types import BaseConfigProtocol
 
-__all__ = ('AwsClient',)
+__all__ = 'AwsClient', 'RequestError'
 logger = logging.getLogger('aioaws.core')
 
 _AWS_AUTH_REQUEST = 'aws4_request'
@@ -51,6 +51,7 @@ class AwsClient:
         if self.service == 'ses':
             self.host = f'email.{self.region}.amazonaws.com'
         else:
+            assert self.service == 's3', self.service
             bucket = get_config_attr(config, 'aws_s3_bucket')
             if '.' in bucket:
                 # assumes the bucket is a domain and is already as a CNAME record for S3
